@@ -153,7 +153,12 @@ xfce_shortcut_conflict_dialog (GtkWindow   *parent,
         owner_button_text = g_strdup_printf (_(conflict_messages[i].owner_button_text), owner_action_name);
         other_button_text = g_strdup_printf (_(conflict_messages[i].other_button_text), other_action_name);
 
-        response = xfce_message_dialog (parent, title, GTK_STOCK_DIALOG_QUESTION,
+        response = xfce_message_dialog (parent, title,
+#if !GTK_CHECK_VERSION (3, 10, 0)
+                                        GTK_STOCK_DIALOG_QUESTION,
+#else
+                                        "dialog-question",
+#endif
                                         title, secondary_text,
                                         XFCE_BUTTON_TYPE_MIXED, NULL, owner_button_text, GTK_RESPONSE_ACCEPT,
                                         XFCE_BUTTON_TYPE_MIXED, NULL, other_button_text, GTK_RESPONSE_REJECT,
@@ -172,9 +177,19 @@ xfce_shortcut_conflict_dialog (GtkWindow   *parent,
 
   if (G_UNLIKELY (!handled))
     {
-      xfce_message_dialog (parent, title, GTK_STOCK_DIALOG_ERROR,
+      xfce_message_dialog (parent, title,
+#if !GTK_CHECK_VERSION (3, 10, 0)
+                           GTK_STOCK_DIALOG_ERROR,
+#else
+                           "dialog-error",
+#endif
                            title, _("This shortcut is already being used for something else."),
-                           GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
+#if !GTK_CHECK_VERSION (3, 10, 0)
+                           GTK_STOCK_CLOSE,
+#else
+                           "window-close",
+#endif
+                           GTK_RESPONSE_CLOSE, NULL);
       response = GTK_RESPONSE_REJECT;
     }
 
