@@ -1,5 +1,4 @@
-/* $Id$ */
-/*-
+/*
  * Copyright (c) 2007 The Xfce Development Team
  *
  * This library is free software; you can redistribute it and/or
@@ -13,9 +12,9 @@
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA
  */
 
 #if !defined (LIBXFCE4UI_COMPILATION)
@@ -32,6 +31,18 @@ G_BEGIN_DECLS
 /* support for canonical representations of strings */
 #define I_(string) (g_intern_static_string ((string)))
 
+#ifndef NDEBUG
+#define _libxfce4ui_assert(expr)                 g_assert (expr)
+#define _libxfce4ui_assert_not_reached()         g_assert_not_reached ()
+#define _libxfce4ui_return_if_fail(expr)         g_return_if_fail (expr)
+#define _libxfce4ui_return_val_if_fail(expr,val) g_return_val_if_fail (expr,val)
+#else
+#define _libxfce4ui_assert(expr)                 G_STMT_START{ (void)0; }G_STMT_END
+#define _libxfce4ui_assert_not_reached()         G_STMT_START{ (void)0; }G_STMT_END
+#define _libxfce4ui_return_if_fail(expr)         G_STMT_START{ (void)0; }G_STMT_END
+#define _libxfce4ui_return_val_if_fail(expr,val) G_STMT_START{ (void)0; }G_STMT_END
+#endif
+
 G_END_DECLS
 
 #endif /* !__LIBXFCE4UI_PRIVATE_H__ */
