@@ -1,5 +1,4 @@
-/* $Id$ */
-/*-
+/*
  * Copyright (c) 2007 The Xfce Development Team
  *
  * This library is free software; you can redistribute it and/or
@@ -13,9 +12,9 @@
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -61,20 +60,28 @@ xfce_gtk_button_new_mixed (const gchar *stock_id,
 
   if (label != NULL)
     {
-      /* create button */
       button = gtk_button_new_with_mnemonic (label);
 
       if (stock_id != NULL)
         {
           /* create image widget */
-          image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON);
+#if !GTK_CHECK_VERSION (3, 10, 0)
+          if (g_str_has_prefix (stock_id, "gtk-"))
+            image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON);
+          else
+#endif
+            image = gtk_image_new_from_icon_name (stock_id, GTK_ICON_SIZE_BUTTON);
           gtk_button_set_image (GTK_BUTTON (button), image);
         }
     }
   else
     {
+#if !GTK_CHECK_VERSION (3, 10, 0)
       /* fall back to a stock button */
       button = gtk_button_new_from_stock (stock_id);
+#else
+      button = gtk_button_new_with_label (label);
+#endif
     }
 
   return button;
@@ -108,7 +115,6 @@ xfce_gtk_frame_box_new (const gchar  *label,
 
   g_return_val_if_fail (container_return != NULL, NULL);
 
-  /* create frame */
   frame = gtk_frame_new (NULL);
   gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
   gtk_frame_set_label_align (GTK_FRAME (frame), 0.0, 1.0);
@@ -116,21 +122,20 @@ xfce_gtk_frame_box_new (const gchar  *label,
   if (G_LIKELY (label != NULL))
     {
       /* create bold label */
-      markup_label = g_strdup_printf ("<b>%s</b>", label);
+      markup_label = g_markup_printf_escaped ("<b>%s</b>", label);
       frame_label = gtk_label_new (markup_label);
+      gtk_label_set_use_markup (GTK_LABEL (frame_label), TRUE);
       g_free (markup_label);
       gtk_misc_set_alignment (GTK_MISC (frame_label), 0.0, 0.5);
       gtk_frame_set_label_widget (GTK_FRAME (frame), frame_label);
       gtk_widget_show (frame_label);
     }
 
-  /* create the container */
   container = gtk_alignment_new (0.0, 0.0, 1.0, 1.0);
   gtk_alignment_set_padding (GTK_ALIGNMENT (container), PADDING, PADDING, PADDING * 3, PADDING);
   gtk_container_add (GTK_CONTAINER (frame), container);
   gtk_widget_show (container);
 
-  /* return container */
   if (G_LIKELY (container_return != NULL))
     *container_return = container;
 
@@ -156,10 +161,7 @@ xfce_gtk_frame_box_new_with_content (const gchar *label,
   GtkWidget *frame;
   GtkWidget *container;
 
-  /* create frame */
   frame = xfce_gtk_frame_box_new (label, &container);
-
-  /* add content */
   gtk_container_add (GTK_CONTAINER (container), content);
 
   return frame;
@@ -190,7 +192,6 @@ xfce_gtk_window_center_on_active_screen (GtkWindow *window)
   /* get the screen with the pointer */
   screen = xfce_gdk_screen_get_active (NULL);
 
-  /* set the window screen */
   gtk_window_set_screen (window, screen);
 
   /* gtk+ handles the centering of the window properly after resize */
